@@ -102,7 +102,7 @@ class SSOBase:
         login_uri = await self.get_login_url()
         response = RedirectResponse(login_uri, 303)
         if self.state is not None:
-            response.set_cookie("ssostate", self.state)
+            response.set_cookie("ssostate", self.state, expires=600)
         return response
 
     async def verify_and_process(self, request: Request) -> Optional[OpenID]:
@@ -115,7 +115,7 @@ class SSOBase:
         Returns:
             Optional[OpenID] -- OpenID if the login was successfull
         """
-        code = request.path_params.get("code")
+        code = request.query_params.get("code")
         if code is None:
             raise SSOLoginError(400, "'code' parameter was not found in callback request")
         if self.state is not None:
